==> haskell-xcffib-1.6.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xcffib
version:              1.6.0
visibility:           public
id:                   xcffib-1.6.0-J8e2VvMAIlZITOexEXzUtT
key:                  xcffib-1.6.0-J8e2VvMAIlZITOexEXzUtT
license:              Apache-2.0
maintainer:           Tycho Andersen <tycho@tycho.pizza>
author:               Tycho Andersen
homepage:             http://github.com/tych0/xcffib
synopsis:             A cffi-based python binding for X
description:          A cffi-based python binding for X, comparable to xpyb
category:             X11
abi:                  31000d081690f3b41b2e5e163e084d4b
exposed:              True
exposed-modules:
    Data.XCB.Python.AST Data.XCB.Python.Parse Data.XCB.Python.PyHelpers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xcffib
hs-libraries:         HSxcffib-1.6.0-J8e2VvMAIlZITOexEXzUtT
depends:
    attoparsec-0.14.4-JY3WRVtwl2HEigkrgC0fwc base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    either-5.0.3-6YhoCpctKpCIYHZXObBGFo
    filemanip-0.3.6.3-7KTORiggyz6FsmZKun1JQr filepath-1.4.2.2 mtl-2.2.2
    pretty-1.1.3.6 split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV
    xcb-types-0.15.0-HIw3n37qHy923j0eWzIL5J

haddock-interfaces:   /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html:         /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcffib-1.6.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xcffib
version:              1.6.0
visibility:           public
id:                   xcffib-1.6.0-D4es9qjYkZ4ComozlfDc0D
key:                  xcffib-1.6.0-D4es9qjYkZ4ComozlfDc0D
license:              Apache-2.0
maintainer:           Tycho Andersen <tycho@tycho.pizza>
author:               Tycho Andersen
homepage:             http://github.com/tych0/xcffib
synopsis:             A cffi-based python binding for X
description:          A cffi-based python binding for X, comparable to xpyb
category:             X11
abi:                  fddd2d3df153d08f88ac834870080142
exposed:              True
exposed-modules:
    Data.XCB.Python.AST Data.XCB.Python.Parse Data.XCB.Python.PyHelpers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xcffib-1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xcffib
hs-libraries:         HSxcffib-1.6.0-D4es9qjYkZ4ComozlfDc0D
depends:
    attoparsec-0.14.4-a7MjceIUMFKMmgfXk7t7H base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    either-5.0.3-9LFBcehmdk7BiW9XTQtRz2
    filemanip-0.3.6.3-JDLRsax15mt5Rj2joW6hsx filepath-1.4.2.2 mtl-2.2.2
    pretty-1.1.3.6 split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV
    xcb-types-0.15.0-HIw3n37qHy923j0eWzIL5J

haddock-interfaces:   /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html:         /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
